import {
  startAuthentication,
  startRegistration
} from "@simplewebauthn/browser";
export * from "@simplewebauthn/browser";
let nanoid = (t = 21) => crypto.getRandomValues(new Uint8Array(t)).reduce(
  (t2, e) => t2 += (e &= 63) < 36 ? e.toString(36) : e < 62 ? (e - 26).toString(36).toUpperCase() : e > 62 ? "-" : "_",
  ""
);
function handleFormSubmit(options, config) {
  return async function handleSubmit(event) {
    var _a, _b;
    if (!(event.nativeEvent instanceof SubmitEvent) || !(event.nativeEvent.submitter instanceof HTMLButtonElement)) {
      event.preventDefault();
      return false;
    }
    if (event.nativeEvent.submitter.formMethod === "get") {
      return true;
    }
    const formData = new FormData(event.currentTarget);
    const username = (_a = formData.get("username")) == null ? void 0 : _a.toString();
    const target = event.currentTarget;
    const submitButtonValue = event.nativeEvent.submitter.value;
    const type = submitButtonValue === "registration" ? "registration" : submitButtonValue === "authentication" ? "authentication" : void 0;
    if (!type) {
      throw new Error(
        'When you submit this form, you need to indicate the intent - whether you are registering a new passkey or authenticating an existing passkey. By default, put `name="intent"` attribute on your submit buttons, and set the `value` attribute to either `"registration"` or `"authentication"`.'
      );
    }
    if (type === "registration" && !username) {
      throw new Error(
        "You must provide a username field in your form, and set the `name` attribute to `username`."
      );
    }
    event.preventDefault();
    const responseValue = type === "authentication" ? JSON.stringify(
      await startAuthentication({
        challenge: options.challenge,
        allowCredentials: options.authenticators,
        rpId: options.rp.id,
        userVerification: "preferred",
        timeout: 90 * 1e3
      })
    ) : JSON.stringify(
      await startRegistration({
        challenge: options.challenge,
        excludeCredentials: options.authenticators,
        rp: options.rp,
        user: {
          id: ((_b = config == null ? void 0 : config.generateUserId) == null ? void 0 : _b.call(config)) || nanoid(),
          name: username,
          displayName: username
        },
        pubKeyCredParams: [
          {
            alg: -7,
            type: "public-key"
          },
          {
            alg: -257,
            type: "public-key"
          }
        ],
        timeout: 90 * 1e3,
        attestation: (config == null ? void 0 : config.attestationType) || "none",
        authenticatorSelection: {
          residentKey: "discouraged",
          requireResidentKey: false
        },
        extensions: { credProps: true }
      })
    );
    let responseEl = target.querySelector(
      'input[name="response"]'
    );
    if (!responseEl) {
      responseEl = Object.assign(document.createElement("input"), {
        type: "hidden",
        name: "response"
      });
      target.prepend(responseEl);
    }
    responseEl.value = responseValue;
    let typeEl = target.querySelector('input[name="type"]');
    if (!typeEl) {
      typeEl = Object.assign(document.createElement("input"), {
        type: "hidden",
        name: "type"
      });
      target.prepend(typeEl);
    }
    typeEl.value = type;
    target.submit();
  };
}
export {
  handleFormSubmit,
  nanoid
};
